==> CloudClientStandardAWS_v2.0.1.zip: com/clustercontrol/ws/cloud/AddInstance.java <==

package com.clustercontrol.ws.cloud;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>addInstance complex typeJavaNXB
 * 
 * <p>̃XL[}EtOǵÃNXɊ܂܂\Recw肵܂B
 * 
 * <pre>
 * &lt;complexType name="addInstance">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="roleId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="region" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="request" type="{http://cloud.ws.clustercontrol.com}createInstanceRequest" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "addInstance", propOrder = {
    "roleId",
    "region",
    "request"
})
public class AddInstance {

    protected String roleId;
    protected String region;
    protected CreateInstanceRequest request;

    /**
     * roleIdvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRoleId() {
        return roleId;
    }

    /**
     * roleIdvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRoleId(String value) {
        this.roleId = value;
    }

    /**
     * regionvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRegion() {
        return region;
    }

    /**
     * regionvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRegion(String value) {
        this.region = value;
    }

    /**
     * requestvpeB̒l擾܂B
     * 
     * @return
     *     possible object is
     *     {@link CreateInstanceRequest }
     *     
     */
    public CreateInstanceRequest getRequest() {
        return request;
    }

    /**
     * requestvpeB̒lݒ肵܂B
     * 
     * @param value
     *     allowed object is
     *     {@link CreateInstanceRequest }
     *     
     */
    public void setRequest(CreateInstanceRequest value) {
        this.request = value;
    }

}

==> CloudClientStandardAWS_v2.0.5.zip: com/clustercontrol/ws/cloud/AddInstance.java <==

package com.clustercontrol.ws.cloud;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>addInstance complex typeのJavaクラス。
 * 
 * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
 * 
 * <pre>
 * &lt;complexType name="addInstance">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="roleId" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="region" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="request" type="{http://cloud.ws.clustercontrol.com}createInstanceRequest" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "addInstance", propOrder = {
    "roleId",
    "region",
    "request"
})
public class AddInstance {

    protected String roleId;
    protected String region;
    protected CreateInstanceRequest request;

    /**
     * roleIdプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRoleId() {
        return roleId;
    }

    /**
     * roleIdプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRoleId(String value) {
        this.roleId = value;
    }

    /**
     * regionプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRegion() {
        return region;
    }

    /**
     * regionプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRegion(String value) {
        this.region = value;
    }

    /**
     * requestプロパティの値を取得します。
     * 
     * @return
     *     possible object is
     *     {@link CreateInstanceRequest }
     *     
     */
    public CreateInstanceRequest getRequest() {
        return request;
    }

    /**
     * requestプロパティの値を設定します。
     * 
     * @param value
     *     allowed object is
     *     {@link CreateInstanceRequest }
     *     
     */
    public void setRequest(CreateInstanceRequest value) {
        this.request = value;
    }

}
